import DescriptionItem from '@/components/DescriptionItem';
import { Flex } from 'antd';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { useLayoutEffect, useMemo, useRef } from 'react';
import BaseCard from '../components/BaseCard';
import styles from './index.less';
import option from './option';

/** @name 管廊感知态势 */
const PipeCorridorSensesTheSituation: React.FC = () => {
  const chartRef = useRef<any>();

  const INFO = useMemo(() => {
    return [
      {
        name: '已接入感知设备',
        value: 82,
        unit: '个',
      },
      {
        name: '在线',
        value: 42,
        unit: '个',
      },
      {
        name: '设备在线率',
        value: 40,
        unit: '%',
        vColor: '#55D355',
      },
    ];
  }, []);

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const BarOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    const xAxis = [
      '液位监测传感器',
      '湿度传感器',
      '温度传感器',
      '硫化氢气体传感器',
      '甲坑气体传盛器',
      '一氧化碳气体传感器',
      '氧气浓度传感器',
    ];
    const yAxis = [1652, 1652, 1652, 1652, 1652, 1652, 1652];
    temp.xAxis[0].data = xAxis;
    temp.series[0].data = yAxis;
    return temp;
  }, []);

  return (
    <BaseCard w={917} h={357} title="管廊感知态势 ">
      <Flex gap={100} style={{ marginTop: 20 }} align="center">
        {INFO.map((item) => {
          return (
            <DescriptionItem
              value={item.value}
              direction="horizontal"
              unit={item.unit}
              valueStyle={{
                margin: '0 12px',
                color: item.vColor,
              }}
              name={item.name}
              key={item.name}
            />
          );
        })}
      </Flex>
      <div>
        <div className={styles.chartTitle}>各类型设备在线率</div>
        <EChartsReact
          ref={chartRef}
          style={{
            height: 150,
          }}
          option={BarOption}
        ></EChartsReact>
      </div>
    </BaseCard>
  );
};

export default PipeCorridorSensesTheSituation;
