import { DoubleRightOutlined } from '@ant-design/icons';
import { useBoolean } from 'ahooks';
import { Flex, Space } from 'antd';
import classNames from 'classnames';
import React, { useEffect, useRef } from 'react';
import BaseCard from '../components/BaseCard';
import styles from './index.less';
const LatestWarning: React.FC = () => {
  const [playingStatus, { setTrue, setFalse }] = useBoolean(true);
  const eventHtmlRef = useRef<HTMLDivElement>(null);

  const dataSource = [
    {
      name: '设备关灯异常告警',
      address: '通威国际中心草坪东2....',
      time: '2024-09-09 12:20',
      type: '告警中',
    },
    {
      name: '设备关灯异常告警',
      address: '通威国际中心草坪东2....',
      time: '2024-09-09 12:20',

      type: '告警中',
    },
    {
      name: '设备关灯异常告警',
      address: '通威国际中心草坪东2....',
      time: '2024-09-09 12:20',

      type: '关闭',
    },
    {
      name: '设备关灯异常告警',
      address: '通威国际中心草坪东2....',
      time: '2024-09-09 12:20',

      type: '关闭',
    },
    {
      name: '设备关灯异常告警',
      address: '通威国际中心草坪东2....',
      time: '2024-09-09 12:20',

      type: '关闭',
    },
  ];

  /** 实现翻牌器滚动 */
  useEffect(() => {
    let intervalId!: NodeJS.Timeout;
    if (!eventHtmlRef.current) {
      return;
    }
    const viewBoxH = eventHtmlRef.current?.clientHeight;

    // 进度条速度
    const speed = 50;

    if (playingStatus) {
      // 开始计时任务
      intervalId = setInterval(() => {
        const top = (eventHtmlRef.current as HTMLDivElement)?.scrollTop;
        if (!eventHtmlRef.current) {
          clearInterval(intervalId);
        }
        if (
          (eventHtmlRef.current as HTMLDivElement)?.scrollHeight - viewBoxH <=
          top + 10
        ) {
          eventHtmlRef.current?.scrollTo({ top: 0, behavior: 'instant' });
          return;
        }
        eventHtmlRef.current?.scrollTo({
          top: top + speed,
          behavior: 'smooth',
        });
      }, 3000);
    } else {
      // 清除定时器
      clearInterval(intervalId);
    }
    // 在组件卸载时清除定时器
    return () => {
      clearInterval(intervalId);
    };
  }, [playingStatus]);

  return (
    <BaseCard
      w={755}
      h={153}
      title="最新告警"
      headerRight={
        <Space
          style={{
            fontSize: 16,
            color: 'rgb(179, 214, 247)',
            cursor: 'pointer',
          }}
        >
          <span>更多</span>
          <DoubleRightOutlined />
        </Space>
      }
    >
      <div
        className={styles.tableBody}
        ref={eventHtmlRef}
        onMouseMove={setFalse}
        onMouseLeave={setTrue}
      >
        {dataSource.map((item, index) => {
          return (
            <Flex
              key={index}
              align="center"
              className={classNames(styles.tableRow, {
                [styles.tableRowWarning]: item.type === '告警中',
              })}
            >
              <img
                src={require('@/assets/images/warn.png')}
                style={{ width: 19, height: 19 }}
                alt=""
              ></img>
              <div className={styles.nameCell}>{item.name}</div>
              <div>{item.address}</div>
              <div>{item.time}</div>
              <div>{item.type}</div>
            </Flex>
          );
        })}
      </div>
    </BaseCard>
  );
};

export default LatestWarning;
