import { Flex } from 'antd';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { useLayoutEffect, useMemo, useRef } from 'react';
import BaseCard from '../components/BaseCard';
import styles from './index.less';
import option from './option';
/** @name 情况 */
const LightingOperationSituation: React.FC = () => {
  const chartRef = useRef<any>();

  const INFO = useMemo(() => {
    return [
      {
        name: '完好率',
        value: 98.5,
        unit: '%',
      },
      {
        name: '亮灯率',
        value: 82,
        unit: '%',
      },
      {
        name: '故障处置及时率',
        value: 98.5,
        unit: '%',
      },
    ];
  }, []);

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const LineOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    const xAxis = [
      '2024年7月',
      '2024年8月',
      '2024年9月',
      '2024年10月',
      '2024年11月',
      '2024年12月',
    ];
    const yAxis = [1652, 1652, 1652, 1652, 1652, 1652, 1652];
    temp.xAxis[0].data = xAxis;

    temp.legend.data = INFO.map((v) => v.name);

    const lineSeries = [
      {
        name: '完好率',
        type: 'line',
        symbol: 'none',
        stack: 'Total',
        lineStyle: {
          // color: '#57efe5',
          width: 3,
        },
        smooth: true,
        data: [120, 132, 101, 134, 90, 230, 210],
      },
      {
        name: '亮灯率',
        type: 'line',
        stack: 'Total',
        lineStyle: {
          // color: '#FFB05A',
          width: 3,
        },
        smooth: true,

        symbol: 'none',
        data: [220, 182, 191, 234, 290, 330, 310],
      },
      {
        name: '故障处置及时率',
        type: 'line',
        stack: 'Total',
        lineStyle: {
          // color: '#FFB05A',
          width: 3,
        },
        smooth: true,

        symbol: 'none',
        data: [180, 122, 111, 134, 170, 230, 210],
      },
    ];
    temp.series = lineSeries;
    return temp;
  }, []);
  return (
    <BaseCard
      w={755}
      h={422}
      title="市管功能照明运行态势"
      headerRight={
        <div style={{ fontSize: 16 }}>
          统计时间范围：2024年11月25日 - 2024年12月24日
        </div>
      }
    >
      <Flex justify="space-between" style={{ marginTop: 20 }} align="center">
        {INFO.map((item) => {
          return (
            <Flex
              className={styles.item}
              align="center"
              justify="center"
              key={item.name}
            >
              <div>{item.name}</div>
              <div>{item.value}</div>
              <div>{item.unit}</div>
            </Flex>
          );
        })}
      </Flex>
      <div>
        <div className={styles.chartTitle}>近半年运行趋势</div>
        <EChartsReact
          ref={chartRef}
          style={{
            height: 150,
          }}
          option={LineOption}
        ></EChartsReact>
      </div>
    </BaseCard>
  );
};

export default LightingOperationSituation;
