import { Flex } from 'antd';
import dayjs from 'dayjs';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { useLayoutEffect, useMemo, useRef } from 'react';
import BaseCard from '../components/BaseCard';
import styles from './index.less';
import option from './option';
/** @name 情况 */
const OperationCondition: React.FC = () => {
  const chartRef = useRef<any>();

  const INFO = useMemo(() => {
    return [
      {
        name: '开灯时间',
        value: '08:00',
        tag: dayjs().format('MM月DD日'),
      },
      {
        name: '关灯时间',
        value: '02:00',
        tag: dayjs().add(1, 'day').format('MM月DD日'),
      },
      {
        name: '自然光照度',
        value: 22122,
        unit: 'lux',
        tag: '实时',
      },
    ];
  }, []);

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const LineOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    const xAxis = [
      '2024年7月',
      '2024年8月',
      '2024年9月',
      '2024年10月',
      '2024年11月',
      '2024年12月',
    ];
    const yAxis = [1652, 1652, 1652, 1652, 1652, 1652, 1652];
    temp.xAxis[0].data = xAxis;

    temp.legend.data = INFO.map((v) => v.name);

    const lineSeries = [
      {
        name: '完好率',
        type: 'line',
        symbol: 'none',
        stack: 'Total',
        lineStyle: {
          color: '#F0FF69',
          width: 3,
        },
        smooth: true,
        areaStyle: {
          color: {
            type: 'linear',
            x: 0,
            y: 0,
            x2: 0,
            y2: 1,
            colorStops: [
              {
                offset: 0,
                color: 'rgb(240, 255, 105,0.26)', // 0% 处的颜色
              },
              {
                offset: 1,
                color: 'rgb(240, 255, 105,0)', // 100% 处的颜色
              },
            ],
            global: false, // 缺省为 false
          },
        },
        data: [120, 132, 101, 134, 90, 230, 210],
      },
    ];
    temp.series = lineSeries;
    return temp;
  }, []);
  return (
    <BaseCard w={755} h={303} title="运行情况">
      <Flex justify="space-between" style={{ marginTop: 10 }} align="center">
        {INFO.map((item) => {
          return (
            <Flex className={styles.item} align="center" key={item.name}>
              <div>{item.name}</div>
              <div>{item.value}</div>
              <div>{item.unit}</div>
              <div className={styles.tag}>{item.tag}</div>
            </Flex>
          );
        })}
      </Flex>
      <div>
        <div className={styles.chartTitle}>昨日功率趋势</div>
        <EChartsReact
          ref={chartRef}
          style={{
            height: 120,
          }}
          option={LineOption}
        ></EChartsReact>
      </div>
    </BaseCard>
  );
};

export default OperationCondition;
