import { Badge, Flex } from 'antd';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { memo, useLayoutEffect, useMemo, useRef, useState } from 'react';
import BaseCard from '../components/BaseCard';
import styles from './index.less';
import { pieOption } from './option';
/** @name 全市已移交纳入管理综合管廊概况 */
const Overview: React.FC = memo(() => {
  const [pieData, setPieData] = useState(
    [...Array(4)].map((_, i) => {
      return {
        value: Math.floor(Math.random() * 100),
        name: '给水（输水）管道' + i,
      };
    }),
  );
  const chartRef = useRef<any>();

  const colors = [
    '#5DDDFF',
    '#A550FF',
    '#F07283',
    '#7664EC',
    '#77E67B',
    '#35B2FF',
    '#FFE335',
    '#FF9B5D',
  ];

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const PieOption = useMemo(() => {
    const temp = cloneDeep(pieOption) as any;
    temp.color = colors;
    temp.series[0].data = pieData;
    return temp;
  }, []);

  return (
    <BaseCard
      w={755}
      h={281}
      title="市管功能照明灯盏数    25.58 万盏    功率   569 千瓦"
    >
      <Flex align="center" gap={60} className={styles.container}>
        <div
          style={{
            height: 130,
            width: 130,
          }}
        >
          <EChartsReact
            ref={chartRef}
            style={{
              height: 130,
              width: 130,
            }}
            option={PieOption}
          ></EChartsReact>
        </div>

        <div className={styles.legendContent}>
          {pieData.map((item, index) => {
            return (
              <Flex key={index} className={styles.legendBg} gap={20}>
                <Badge color={colors[index % colors.length]} />

                <div>{item.name}</div>
                <div>{item.value} 万盏</div>
                <div>56.25 %</div>
              </Flex>
            );
          })}
        </div>
      </Flex>
    </BaseCard>
  );
});

export default Overview;
