import { Badge, Flex } from 'antd';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { useLayoutEffect, useMemo, useRef, useState } from 'react';
import BaseCard from '../components/BaseCard';
import styles from './index.less';
import option from './option';
/** @name 感知设备 */
const SensingDevice: React.FC = () => {
  const chartRef = useRef<any>();

  const colors = [
    '#5DDDFF',
    '#A550FF',
    '#F07283',
    '#7664EC',
    '#77E67B',
    '#35B2FF',
    '#FFE335',
    '#FF9B5D',
  ];

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const [pieData, setPieData] = useState(
    [...Array(5)].map((_, i) => {
      return {
        value: Math.floor(Math.random() * 100),
        name: '给水（输水）管道' + i,
      };
    }),
  );

  const PieOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    temp.color = colors;
    temp.series[0].data = pieData;
    return temp;
  }, []);

  return (
    <BaseCard w={755} h={222} title="感知设备  15.28 万个">
      <Flex align="center" gap={30} className={styles.container}>
        <div
          style={{
            height: 120,
            width: 120,
          }}
        >
          <EChartsReact
            ref={chartRef}
            style={{
              height: 120,
              width: 120,
            }}
            option={PieOption}
          ></EChartsReact>
        </div>

        <div className={styles.legendContent}>
          {pieData.map((item, index) => {
            return (
              <div key={index} className={styles.legendBg}>
                <Badge color={colors[index % colors.length]} text={item.name} />
                <div className={styles.legendText}>{item.value}</div>
                <div>个</div>
              </div>
            );
          })}
        </div>
      </Flex>
    </BaseCard>
  );
};

export default SensingDevice;
